/**
 * @file demo api for dishClassify
 * @author swan
 */
/* globals Page, swan */

/* eslint-disable */
let app = getApp();

Page({
    /* eslint-enable */
    data: {
        loading: true,
        isLoad: false,
        iPhoneX: false,
        height: 'auto',
        image: 'https://b.bdstatic.com/miniapp/images/dishClassify.png',
        result: [
            {calorie: '123cal/100g', 'has_calorie': true, name: '咖喱牛腩', probability: '29.17', score: 0},
            {calorie: '171cal/100g', 'has_calorie': true, name: '咖喱鸡', probability: '8.06', score: 0},
            {calorie: '98.98cal/100g', 'has_calorie': true, name: '番茄炖牛腩', probability: '6.36', score: 0},
            {calorie: '87cal/100g', 'has_calorie': true, name: '咖喱饭', probability: '5.62', score: 0},
            {calorie: '226cal/100g', 'has_calorie': true, name: '石锅酱汤', probability: '4.43', score: 0}
        ]
    },
    onLoad(e) {
        swan.getSystemInfo({
            success: res => {
                this.setData('iPhoneX', /iPhone X/.test(res.model));
            }
        });
    },
    onShow() {
        // 打点操作
        var openParams= app.globalData.openParams;
        if (openParams) {
            swan.reportAnalytics('pageshow', {
                fr: openParams,
                type: 'api',
                name: 'dishClassify',
            });
        }
        if (!this.getData('isLoad')) {
            swan.showToast({
                title: '识别中...',
                icon: 'loading',
                duration: 1000
            });
            this.setData({
                loading: true
            });

            setTimeout(() => {
                this.setData({
                    loading: false,
                    isLoad: true
                });
             }, 1000);
        }
    },
    onHide() {
        getApp().globalData.openParams = ''
    },
    dishClassify() {
        if (this.getData('loading')) {
            return;
        }
        swan.showActionSheet({
            itemList: ['拍照', '从手机相册选择'],
            success: res => {
                const sourceType = res.tapIndex === 0 ? 'camera' : 'album';
                swan.chooseImage({
                    count: 1,
                    sizeType: ['original', 'compressed'],
                    sourceType: [sourceType],
                    success: res => {
                        const image = res.tempFilePaths[0];
                        this.setData({image, loading: true, height: '100%'});
                        swan.showToast({
                            title: '识别中...',
                            icon: 'loading',
                            duration: 20000
                        });
                        swan.ai.dishClassify({
                            image,
                            top_num: 5,
                            filter_threshold: 0.95,
                            success: res => {
                                console.log('dishClassify success', res);
                                this.setImageData(res.result);
                            },
                            fail: err => {
                                console.log('dishClassify fail', err);
                            },
                            complete: () => {
                                swan.hideToast();
                                this.setData({
                                    loading: false,
                                    height: 'auto'
                                });
                            }
                        });
                    },
                    fail: err => {
                        console.log('chooseImage fail', err);
                    }
                });
            }
        });
    },
    setImageData(data) {
        const len = data.length - 1;
        for (let i = len; i >= 0; i--) {
            if (data[i].name === '非菜') {
                data.splice(i, 1);
                continue;
            }

            if (data[i].probability && !isNaN(data[i].probability)) {
                data[i].probability = (data[i].probability * 100).toFixed(2);
                if (data[i].probability >= 100) {
                    data[i].probability = 100;
                }
            } else {
                data[i].probability = 0;
            }

            if (data[i].calorie) {
                data[i].calorie += 'cal/100g';
            }
        }
        this.setData('result', data);
    }
});
