/**
 * @file demo api for faceDetect
 * @author swan
 */

let app = getApp();

Page({
    data: {
        loading: true,
        isLoad: false,
        iPhoneX: false,
        height: 'auto',
        hasFace: false,
        image: 'https://b.bdstatic.com/miniapp/image/faceDetect.png',
        result: [
            {name: '年龄', value: '22'},
            {name: '颜值', value: '60'},
            {name: '表情', value: '不笑'},
            {name: '姿势', value: '平视'},
            {name: '脸型', value: '圆形'},
            {name: '性别', value: '女性'},
            {name: '眼镜', value: '不戴眼镜'},
            {name: '眼睛', value: '双眼睁开'},
            {name: '人种', value: '黄种人'},
            {name: '完整度', value: '完整'}
        ]
    },
    onLoad(e) {
        swan.getSystemInfo({
            success: res => {
                this.setData('iPhoneX', /iPhone X/.test(res.model));
            }
        });
    },
    onShow() {
        // 打点操作
        var openParams= app.globalData.openParams;
        if (openParams) {
            swan.reportAnalytics('pageshow', {
                fr: openParams,
                type: 'api',
                name: 'faceDetect',
            });
        }
        if (!this.getData('isLoad')) {
            swan.showToast({
                title: '识别中...',
                icon: 'loading',
                duration: 1000
            });
            this.setData({
                loading: true
            });
            setTimeout(() => {
                this.setData({
                    loading: false,
                    isLoad: true
                });
             }, 1000);
        }
    },
    onHide() {
        getApp().globalData.openParams = ''
    },
    description(){
        swan.showModal({
            title: '识别规则说明',
            content: '此示例中，多张人脸的图片只识别面积最大的人脸（实际可识别全部人脸）',
            confirmText: '我知道了',
            showCancel: false
        });
    },
    faceDetect() {
        if (this.getData('loading')) {
            return;
        }
        swan.showActionSheet({
            itemList: ['拍照', '从手机相册选择'],
            success: res => {
                const sourceType = res.tapIndex === 0 ? 'camera' : 'album';
                let that = this;
                swan.chooseImage({
                    count: 1,
                    sizeType: ['original', 'compressed'],
                    sourceType: [sourceType],
                    success: res => {
                        const image = res.tempFilePaths[0];
                        this.setData({image: image, loading: true, height: '100%'});
                        swan.showToast({
                            title: '识别中...',
                            icon: 'loading'
                        });
                        swan.ai.faceDetect({
                            image,
                            image_type: 'BASE64',
                            face_field: 'age,beauty,angle,expression,face_shape,gender,glasses,eye_status,race,quality',
                            max_face_num: '1',
                            face_type: 'LIVE',
                            success: res => {
                                this.setData('hasFace', false);
                                this.setImageData(res.result);
                            },
                            fail: err => {
                                console.log('ai.faceDetect fail', err);
                                if (err.errCode === 222202) {
                                    this.setData('hasFace', true);
                                }
                            },
                            complete: () => {
                                swan.hideToast();
                                this.setData({
                                    loading: false,
                                    height: 'auto'
                                });
                            }
                        });
                    },
                    fail: err => {
                        console.log('chooseImage fail', err);
                    }
                });
            }
        });
    },
    setImageData(data) {
        const dataResult = data.face_list[0];
        let newResult = this.getData('result');
        if (dataResult.age) {
            let age = parseInt(dataResult.age);
            newResult[0].value = age;
        } 
        else {
            newResult[0].value = "无法识别";
        }

        if (dataResult.beauty) {
            let beauty = parseInt(dataResult.beauty);
            newResult[1].value = beauty;
        }
        else {
            newResult[1].value = "无法识别";
        }

        if (dataResult.expression) {
            switch (dataResult.expression.type) {
                case 'none':
                    newResult[2].value = '不笑'
                   break;
                case 'smile':
                    newResult[2].value = '微笑'
                   break;
                case 'laugh':
                    newResult[2].value = '大笑'
                  break;
           } 
        }
        else {
            newResult[2].value = "无法识别";
        }

        if (dataResult.angle) {
            let pitch = dataResult.angle.pitch;
            if (pitch < -20 && pitch >90) {
                newResult[3].value = '仰头' 
            }
            else if (pitch < 20 && pitch >= -20) {
                newResult[3].value = '平视' 
            }
            else if ( pitch < 90 && pitch >= 20) {
                newResult[3].value = '低头' 
            }  
        } 
        else {
            newResult[3].value = "无法识别";
        }

        if (dataResult.face_shape) {
            switch (dataResult.face_shape.type) {
                case 'square':
                    newResult[4].value = '正方形'
                   break;
                case 'triangle':
                    newResult[4].value = '三角形'
                   break;
                case 'oval':
                    newResult[4].value = '椭圆'
                  break;
                  case 'heart':
                    newResult[4].value = '心形'
                  break;
                  case 'round':
                    newResult[4].value = '圆形'
                  break;
            }
        }
        else {
            newResult[4].value = "无法识别";
        }

        if (dataResult.gender) {
            switch (dataResult.gender.type) {
                case 'male':
                    newResult[5].value = '男性'
                   break;
                case 'female':
                    newResult[5].value = '女性'
                   break;
            } 
        }
        else {
            newResult[5].value = "无法识别";
        }

        if (dataResult.glasses) {
            switch (dataResult.gender.type) {
                case 'none':
                    newResult[6].value = '无眼镜'
                   break;
                case 'common':
                    newResult[6].value = '普通眼镜'
                   break;
                case 'sun':
                    newResult[6].value = '墨镜'
                break;
            } 
        }
        else {
            newResult[6].value = "无法识别";
        }

        if (dataResult.eye_status) {
            let leftEye = dataResult.eye_status.left_eye;
            let rightEye = dataResult.eye_status.right_eye;
            if (leftEye < 0.5 && rightEye > 0.5) {
                newResult[7].value = '右眼睁开' 
            }
            else if (leftEye < 0.5 && rightEye < 0.5) {
                newResult[7].value = '闭眼' 
            }
            else if (leftEye > 0.5 && rightEye > 0.5) {
                newResult[7].value = '睁眼' 
            }   
            else if (leftEye > 0.5 && rightEye < 0.5) {
                newResult[7].value = '左眼睁开' 
            }
        }
        else {
            newResult[7].value = "无法识别";
        }

        if (dataResult.race) {
            switch (dataResult.race.type) {
                case 'yellow':
                    newResult[8].value = '黄种人'
                   break;
                case 'white':
                    newResult[8].value = '白种人'
                   break;
                case 'black':
                    newResult[8].value = '黑种人'
                break;
                case 'arabs':
                    newResult[8].value = '阿拉伯人'
                break;
            }    
        }
        else {
            newResult[8].value = "无法识别";
        }

        if (dataResult.quality) {
            switch (dataResult.quality.completeness) {
                case 1:
                    newResult[9].value = '人脸显示完整'
                    break;
                case 0:
                    newResult[9].value = '人脸溢出图像边界'
                    break;
            } 
        }
        else {
            newResult[9].value = "无法识别";
        }

        this.setData('result', newResult);
    }
});
