/**
 * @file demo api for faceMatch
 * @author swan
 */

let app = getApp();

Page({
    data: {
        loading: true,
        isLoad: false,
        iPhoneX: false,
        height: 'auto',
        imageLeft: 'https://b.bdstatic.com/miniapp/images/faceMatchLeft.png',
        imageRight: 'https://b.bdstatic.com/miniapp/images/faceMatchRight.png',
        percent: 93,
        text: '有可能是同一个人',
        hasResult: true,
        disabled: true,
        whitchPic: '',
        picRight: false,
        picLeft: false,
        imageRightType: 'URL',
        imageLeftType: 'URL'
    },
    onLoad(e) {
        swan.getSystemInfo({
            success: res => {
                this.setData('iPhoneX', /iPhone X/.test(res.model));
            }
        });
    },
    onShow() {
        // 打点操作
        var openParams= app.globalData.openParams;
        if (openParams) {
            swan.reportAnalytics('pageshow', {
                fr: openParams,
                type: 'api',
                name: 'faceMatch',
            });
        }
        if (!this.getData('isLoad')) {
            swan.showToast({
                title: '识别中...',
                icon: 'loading',
                duration: 1000
            });
            this.setData({
                loading: true
            });
            setTimeout(() => {
                this.setData({
                    loading: false,
                    isLoad: true,
                    disabled: false
                });
             }, 1000);
        }
    },
    onHide() {
        getApp().globalData.openParams = ''
    },
    upLoadImage(e) {
        const target = e.currentTarget.dataset.say;
        swan.showActionSheet({
            itemList: ['拍照', '从手机相册选择'],
            success: res => {
                this.setData({loading: true});
                const sourceType = res.tapIndex === 0 ? 'camera' : 'album';
                swan.chooseImage({
                    count: 1,
                    sizeType: ['original', 'compressed'],
                    sourceType: [sourceType],
                    success: res => {
                        const image = res.tempFilePaths[0];
                        if (target === 'left') {
                            this.setData({imageLeft: image, height: '100%', imageLeftType: 'BASE64'});
                        }
                        else if (target === 'right'){
                            this.setData({imageRight: image,  height: '100%', imageRightType: 'BASE64'});
                        }
                    },
                    fail: err => {
                        console.log('chooseImage fail', err);
                    }
                });
            }
        });   
    },
    faceMatch() {
        this.setData({
            loading: true,
            disabled: true,
            picLeft: false,
            picRight: false
        });
        let imageLeft = this.getData('imageLeft');
        let imageRight = this.getData('imageRight');
        let imageRightType = this.getData('imageRightType');
        let imageLeftType = this.getData('imageLeftType');
        swan.showToast({
            title: '识别中...',
            icon: 'loading'
        }); 
        let that = this;
        swan.ai.faceDetect({
            'image': imageLeft,
            'image_type': imageLeftType,
            fail: err => {
                if (err.errCode === 222202) {
                    that.setData('picLeft', true);
                }
            }
        });
        swan.ai.faceDetect({
            'image': imageRight,
            'image_type': imageRightType,
            fail: err => {
                if (err.errCode === 222202) {
                    that.setData('picRight', true);
                }
            }
        });
        setTimeout(() => {
            let Right = this.getData('picRight');
            let Left = this.getData('picLeft');
            if (Right && Left) {
                that.setData('whitchPic', '两图');
            }
            else if (Right) {
                that.setData('whitchPic', '右图');
            }
            else if (Left) {
                that.setData('whitchPic', '左图');
            }
            else {
                that.setData({
                    hasResult: true
                });
            }
        }, 1000);
        swan.ai.faceMatch({
            data: [{
                    'image': imageLeft,
                    'image_type': imageLeftType,
                    'face_type': 'LIVE',
                    'quality_control': 'NONE',
                    'liveness_control': 'NONE'
                },
                {
                    'image': imageRight,
                    'image_type': imageRightType,
                    'face_type': 'LIVE',
                    'quality_control': 'NONE',
                    'liveness_control': 'NONE'
                }],
            success: res =>  {
                console.log('faceMatch success', res);
                let score = parseInt(res.result.score);
                that.setData('percent', score);
                if (score < 25) {
                    that.setData('text', '很可能不是同一个人');
                }
                else if (score <= 50 && score > 25) {
                    that.setData('text', '有可能不是同一个人');
                }
                else if (score <= 75 && score > 50) {
                    that.setData('text', '有可能是同一个人');
                }
                else if (score <= 100 && score > 75) {
                    that.setData('text', '很可能是同一个人');
                }
                that.setData({
                    hasResult: true
                });
            },
            fail: err => {
                console.log('faceMatch fail', err);
                if(err.errCode == 222202){
                    that.setData({
                        hasResult: false
                    });
                }
            },
            complete () {
                setTimeout(() => {
                    that.setData({
                        loading: false,
                        disabled: false
                    });
                    swan.hideToast();
                }, 1000);
            }
        });
    }
});
