/**
 * @file demo api for file
 * @author swan
 */
/* globals Page, swan */

let app = getApp();

Page({
    data: {
        filePath: '',
        disabled: true
    },
    saveFile() {
        this.toast('正在保存', 'loading');
        swan.downloadFile({
            url: 'https://smartprogram.baidu.com/docs/img/file-simple.pdf',
            success: res => {
                swan.saveFile({
                    tempFilePath: res.tempFilePath,
                    success: res => {
                        this.toast('保存成功', 'none');
                        this.setData({
                            'filePath': res.savedFilePath,
                            'disabled': false
                        });
                    },
                    fail: err => {
                        this.toast('保存失败，请稍后重试', 'none');
                    }
                });
            },
            fail: err => {
                this.toast('保存失败，请稍后重试', 'none');
            }
        });
    },
    openFile() {
        const filePath = this.getFile('请先保存文件');
        if (!filePath) {
            return;
        }

        swan.openDocument({
            filePath,
            fileType: 'pdf'
        });
    },
    getSavedFileList() {
        swan.getSavedFileList({
            success: res => {
                this.toast('保存失败，请稍后重试', 'none');
                swan.showModal({
                    title: '文件列表信息',
                    content: '目前保存文件数' + res.fileList.length,
                    showCancel: false
                });
                console.log('getSavedFileList success', res);
            },
            fail: err => {
                this.toast('fail', 'none');
                console.log('getSavedFileList fail', err);
            }
        });
    },

    getSavedFileInfo() {
        const filePath = this.getFile('请先保存文件');
        if (!filePath) {
            return;
        }
        swan.getSavedFileInfo({
            filePath,
            success: res => {
                swan.showModal({
                    title: '文件信息',
                    content: JSON.stringify(res),
                    showCancel: false
                });
                console.log('getSavedFileInfo success', res);
            },
            fail: err => {
                this.toast('fail', 'none');
                console.log('getSavedFileInfo fail', err);
            }
        });
    },
    
    getFileInfo() {
        const filePath = this.getFile('请先保存文件');
        if (!filePath) {
            return;
        }
        swan.getFileInfo({
            filePath,
            digestAlgorithm: 'md5',
            success: res => {
                swan.showModal({
                    title: '文件信息',
                    content: JSON.stringify(res),
                    showCancel: false
                });
                console.log('getFileInfo success', res);
            },
            fail: err => {
                this.toast('fail', 'none');
                console.log('getFileInfo success', err);
            }
        });
    },
    deleteFile() {
        const filePath = this.getFile('无可删除文件');
        if (!filePath) {
            return;
        }

        swan.removeSavedFile({
            filePath,
            success: res => {
                this.setData('filePath', '');
                this.setData('disabled', true);
                this.toast('已删除', 'none');
            },
            fail: err => {
                this.toast('操作失败，请稍后重试', 'none');
            }
        });
    },
    getFile(errTips) {
        const filePath = this.getData('filePath');
        if (!filePath) {
            this.toast(errTips, 'none');
        }
        return filePath;
    },
    toast(title, icon) {
        swan.showToast({title, icon});
    }
});
