/**
 * @file demo api for getVoiceRecognizer
 * @author swan
 */

/* globals Page, swan */
let timer;
/* eslint-disable */
let app = getApp();

Page({
    /* eslint-enable */
    data: {
        vad: 'dnn',
        msg: '',
        currentData: 0,
        desc: false,
        load: true,
        longLoad: true,
        longMsg: '',
        voiceStatus: true,
        num: 1,
        tip: true,
        descLong: true,
        text: '结束',
        type: 'stop',
        Status: '语音识别结果在这里显示',
        StatusTipOn: false,
        ifResult: false
    },
    onLoad(e) {
    },
    onShow() {
        // 打点操作
        var openParams = app.globalData.openParams;
        if (openParams) {
            swan.reportAnalytics('pageshow', {
                fr: openParams,
                type: 'api',
                name: 'getVoiceRecognizer'
            });
        }
        this.voiceManager = swan.ai.getVoiceRecognizer();
        this.stop();
        clearInterval(timer);
        this.setData({
            msg: '',
            ifResult: false,
            desc: false,
            load: true,
            longLoad: true,
            descLong: true,
            longMsg: '',
            num: 1,
            StatusTipOn: false
        });
    },
    onReady() {
        this.voiceManager = swan.ai.getVoiceRecognizer();
    },
    checkCurrent(e) {
        if (!e.target.dataset.current) {
            return;
        }

        const current = parseInt(e.target.dataset.current, 10);
        if (this.getData('currentData') !== current) {
            this.setData({
                currentData: current
            }, () => {
                this.onShow();
           });
        }
    },
    onHide() {
        getApp().globalData.openParams = ''
    },
    radioChange(e) {
        let tip = this.getData('tip');
        this.setData({
            vad: e.detail.value,
            tip: !tip
        });
        this.onShow();
    },
    begin() {
        clearInterval(timer);
        this.setData({
            load: true,
            num: 1
        });
    },
    over() {
        let va = this.getData('vad');
        if (va === 'dnn') {
            this.setData({
                text: '重新开始',
                type: 'start'
            });
        } else {
            this.setData({
                text: '结束',
                type: 'stop'
            });
        }

        this.setData({
            voiceStatus: true,
            msg: '',
            load: false,
            desc: false,
            Status: '正在检测语音...'
        });
    },
    timer() {
        let num = this.getData('num');
        timer = setInterval(() => {
            num = num + 1;
            this.setData('num', num);
            if (num > 50) {
                let time = 60 - num;
                this.setData({
                    StatusTipOn: true,
                    StatusTip: '即将超时 00:0' + time
                });
            }
            if (num > 59) {
                this.begin();
                this.setData({
                    voiceStatus: false,
                    StatusTip: '识别时间超过60s'
                });

            }
        }, 1000);
    },
    start() {
        let vm = this;
        this.voiceManager.onStart(() => {
            vm.setData({
                desc: true,
                ifResult: false,
                StatusTipOn: false
            });
            // swan.showToast({
            //     title: 'start'
            // });
        });
        let vad = this.getData('vad') + '';
        // swan.showToast({
        //     title: vad
        // });
        let newstart = this.getData('text');
        if (newstart === '重新开始') {
            clearInterval(timer);
            this.setData({
                num: 1,
                Status: '已重新开始'
            });
        }
        this.timer();
        this.over();
        let query = swan.createSelectorQuery();
        this.voiceManager.onRecognize(res => {
            vm.setData('msg', res.result);
            // vm.setData('desc', true);
            vm.setData('ifResult', true);
            query.select('.scroll').boundingClientRect(function (rects) {
                vm.setData({
                    scrollTop: rects.height
                });
            }).exec();
        });
        this.voiceManager.onFinish(res => {
            this.setData('ifResult', true);
            this.begin();
            this.setData({
                msg: res.result,
                desc: false,
                voiceStatus: true
            });
        });
        this.voiceManager.onError(err => {
            console.log(err);
            this.setData({
                desc: true
            });

            this.begin();
            if (err.errorCode === 2002) {
                this.setData({
                    msg: '',
                    voiceStatus: false,
                    Status: '没有检测到声音'
                });
            }
            else if(err.errorCode === 9000) {
                this.setData({
                    voiceStatus: false,
                    Status: '遇到未知错误导致语音中断'
                });
            }
        });
        const options = {
            mode: vad,
            longSpeech: false,
            context: 'input'
        };

        this.voiceManager.start(options);
    },
    cancel() {
        this.onShow();
        this.voiceManager.cancel();
        this.setData({
            longLoad: true,
            longMsg: '',
            descLong: true,
            msg: ''
        });
    },
    stop() {
        this.voiceManager.stop();
    },
    longStart() {
        let vm = this;
        this.voiceManager.onStart(() => {
            // swan.showToast({
            //     title: 'longstart'
            // });
        });
        this.setData({
            longLoad: false,
            desc: true,
            descLong: true,
            longDesc: '正在检测语音...',
            longVoiceStatus: true,
            longMsg: ''
        });
        let query = swan.createSelectorQuery();
        let longMsgResult = '';
        this.voiceManager.onRecognize(res => {
            this.setData({descLong: false});
            query.select('.longScroll').boundingClientRect(function (rects) {
                vm.setData({
                    scrollTop: rects.height
                });
            }).exec();
        });
        this.voiceManager.onFinish(res => {
            console.log('res', res);
            longMsgResult += res.result;
            this.setData('longMsg', longMsgResult);
        });
        this.voiceManager.onError(err => {
            if (err.errorCode === 2002) {
                this.setData({
                    longDesc: '没有检测到语音'
                });
            }
        });
        const options = {
            longSpeech: true,
            context: 'input'
        };
        this.voiceManager.start(options);
    },
    longStop() {
        this.voiceManager.stop();

        setTimeout(() => {
            const msg = this.getData('longMsg');
            const longDesc = msg ? '识别结束' : '没有检测到语音';
            this.setData({longDesc, longLoad: true});
        }, 500);
    }
});
