/**
 * @file demo api for imageAudit
 * @author swan
 */

/* globals Page, swan */
let app = getApp();

Page({
    data: {
        src: '',
        ifImg: true,
        default: true,
        loading: true,
        isLoad: false,
        disabled: false,
        detailMessage: false,
        hasResult: false,
        textResult: '通过',
        color: 'true',
        image: 'https://b.bdstatic.com/miniapp/images/carClassify.png'
    },

    onLoad(e) {
    },

    onShow() {
        var openParams = app.globalData.openParams;
        if (openParams) {
            swan.reportAnalytics('pageshow', {
                fr: openParams,
                type: 'api',
                name: 'imageAudit',
            });
        }
        if (!this.getData('isLoad')) {
            swan.showToast({
                title: '识别中...',
                icon: 'loading',
                duration: 1000
            });
            this.setData({
                loading: true
            });

            setTimeout(() => {
                this.setData({
                    loading: false,
                    isLoad: true
                });
             }, 1000);
        }
    },
    onHide() {
        getApp().globalData.openParams = ''
    },
    chooseImage() {
        swan.chooseImage({
            count: 1,
            sizeType: ['original', 'compressed'],
            sourceType: ['album', 'camera'],
            success: res => {
                const image = res.tempFilePaths[0];
                swan.showToast({
                    title: '识别中...',
                    icon: 'loading',
                    duration: 20000
                });
                this.setData({
                    image: image,
                    ifImg: false,
                    default: true,
                    detailMessage: false,
                    loading: true
                });
                this.submit();
            },
            fail: err => {
                console.log('chooseImage fail', err);
            }
        });
    },
    submit() {
        const image = this.getData('image');
        if (image === '') {
            swan.showToast({
                title: '请上传图片',
                icon: 'none'
            });
            return;
        }

        swan.getNetworkType({
            success: res => {
                if (res.networkType === 'none') {
                    swan.showToast({
                        title: '网络不给力，请稍后重试',
                        icon: 'none'
                    });
                } else {
                    this.imageAudit(image);
                }
            }
        });
    },
    imageAudit(image) {
        this.setData({
            isloading: true,
            disabled: true
        });

        swan.ai.imageAudit({
            image,
            success: res => {
                this.setData({
                    isloading: false,
                    disabled: false,
                    default: false,
                    fail: false,
                    detail: res.data,
                });

                switch (res.conclusionType) {
                    case 1:
                        this.setData({
                            textResult: '通过',
                            color: true,
                            detailMessage: false
                        });
                        break;
                    case 2:
                        this.setData({
                            textResult: '违规',
                            color: false,
                            detailMessage: true
                        });
                        break;
                    case 3:
                        this.setData({
                            textResult: '疑似违规',
                            color: false,
                            detailMessage: true
                        });
                        break;
                    case 4:
                        this.setData({
                            textResult: '审核失败',
                            color: false,
                            fail: true,
                            detailMessage: false
                        });
                        break;
                }
            },
            fail: () => {
                this.setData({
                    detailMessage: false,
                    isloading: false,
                    disabled: false,
                    default: false,
                    fail: true,
                    color: false,
                    textResult: '审核失败'
                });
            },
            complete:() => {
                this.setData({
                    hasResult: true,
                    loading: false
                });
                swan.hideToast();
            }
        });
    },
    clearImage() {
        let image = this.getData('src');
        if (image === '') {
            swan.showToast({
                title: '请上传图片',
                icon: 'none'
            });
        } else {
            this.setData({
                ifImg: true,
                default: true,
                detailMessage: false,
                disabled: false,
                src: ''
            });
        }
    }
});
