/**
 * @file demo api for ocrBankCard
 * @author swan
 */
/* globals Page, swan */

/* eslint-disable */
let app = getApp();

Page({
    /* eslint-enable */
    data: {
        image: '',
        bankName: '招商银行',
        bankCardType: '信用卡',
        bankCardNumber: '6225 7688 8888 8888',
        loading: true,
        isLoad: false,
        recognizeEnd: true,
        recognizeSuccess: false,
        image: 'https://b.bdstatic.com/miniapp/image/ocrBankCard.png'
    },
    onLoad(e) {
    },
    onShow() {
        // 打点操作
        var openParams= app.globalData.openParams;
        if (openParams) {
            swan.reportAnalytics('pageshow', {
                fr: openParams,
                type: 'api',
                name: 'ocrBankCard',
           });
        }
        if (!this.getData('isLoad')) {
            swan.showToast({
                title: '识别中...',
                icon: 'loading',
                duration: 1000
            });
            this.setData({
                loading: true
            });

            setTimeout(() => {
                this.setData({
                    loading: false,
                    isLoad: true
                });
             }, 1000);
        }
    },
    onHide() {
        getApp().globalData.openParams = ''
    },
    selectImage() {
        if (this.getData('loading')) {
            return;
        }

        swan.showActionSheet({
            itemList: ['拍照', '从手机相册选择'],
            success: res => {
                const sourceType = res.tapIndex === 0 ? 'camera' : 'album';
                swan.chooseImage({
                    count: 1,
                    sizeType: ['original', 'compressed'],
                    sourceType: [sourceType],
                    success: image => {
                        this.setData({'image': image.tempFilePaths[0], loading: true});
                        swan.showToast({
                            title: '识别中...',
                            icon: 'loading',
                            duration: 20000
                        });
                        this.recognition();
                    },
                    fail: err => {}
                });
            }
        });
    },
    sumbit() {
        const result = swan.isLoginSync();
        if (!result.isLogin) {
            this.toast('请先登录再使用AI能力');
            return;
        }

        if (!this.getData('image')) {
            this.toast('请上传图片');
            return;
        }

        this.isNetConnect().then(() => {
            this.setData('loading', true);
            this.recognition();
        }).catch(() => {
            this.toast('网络不给力，请稍后重试');
        });
    },
    recognition() {
        swan.ai.ocrBankCard({
            image: this.getData('image'),
            success: res => {
                console.log('ocrBankCard succ', res);
                this.setRecognitionResult(res.result);
            },
            fail: err => {
                console.log('ocrBankCard fail', err);
                this.setData({
                    recognizeEnd: false,
                    recognizeSuccess: false
                });
            },
            complete: () => {
                this.setData('loading', false);
                swan.hideToast();
            }
        });
    },
    setRecognitionResult(data) {
        const bankName = data.bank_name;
        const bankCardNumber = data.bank_card_number;
        let bankCardType = data.bank_card_type;
        if (bankCardType === 0) {
            bankCardType = '不能识别';
        } else if (bankCardType === 1) {
            bankCardType = '借记卡';
        } else if (bankCardType === 2) {
            bankCardType = '信用卡';
        }

        let recognizeSuccess = true;
        if (data.bank_card_type === 0 && bankName === '') {
            recognizeSuccess = false;
        }

        this.setData({
            bankName,
            bankCardType,
            bankCardNumber,
            recognizeEnd: true,
            recognizeSuccess
        });
    },
    clear() {
        if (!this.getData('image')) {
            this.toast('请上传图片');
            return;
        }

        if (this.getData('loading')) {
            return;
        }

        this.setData({
            image: 'https://b.bdstatic.com/miniapp/image/ocrBankCard.png',
            bankName: '',
            bankCardType: '',
            bankCardNumber: '',
            loading: false,
            recognizeEnd: false,
            recognizeSuccess: false
        });
    },
    toast(title, icon = 'none') {
        swan.showToast({title, icon});
    },
    isNetConnect() {
        return new Promise((resolve, reject) => {
            swan.getNetworkType({
                success: res => {
                    if (res.networkType.toLowerCase() === 'none') {
                        reject();
                    }
                    resolve();
                },
                fail: reject
            });
        });
    }
});
