/**
 * @file demo api for ocrDrivingLicense
 * @author swan
 */
/* globals Page, swan */

const dataScheme = ['证号', '姓名', '性别', '国籍', '住址', '出生日期', '初次领证日期', '准驾车型', '有效期限'];

/* eslint-disable */
let app = getApp();

Page({
    /* eslint-enable */
    data: {
        drivingLicenseInfoList: [
            {key: '证号', value: '990614199911240066', error: false},
            {key: '姓名', value: '袁运筹', error: false},
            {key: '性别', value: '男', error: false},
            {key: '国籍', value: '中国', error: false},
            {key: '住址', value: '江苏省南京市江宁区', error: false},
            {key: '出生日期', value: '19911206', error: false},
            {key: '初次领证日期', value: '20130316', error: false},
            {key: '准驾车型', value: 'C1', error: false},
            {key: '有效期限', value: '20130316', error: false}],
        image: '',
        loading: true,
        isLoad: false,
        recognizeEnd: false,
        imageDeg: 0,
        imageScale: 1,
        image: 'https://b.bdstatic.com/miniapp/image/ocrDrivingLicense.png'
    },
    onLoad(e) {
        swan.getNetworkType({
            success: res => {
                this.setData('noNet', res.networkType === 'none');
            }
        });
    },
    onShow() {
        // 打点操作
        var openParams= app.globalData.openParams;
        if (openParams) {
            swan.reportAnalytics('pageshow', {
                fr: openParams,
                type: 'api',
                name: 'ocrDrivingLicense',
           });
        }
        if (!this.getData('isLoad')) {
            swan.showToast({
                title: '识别中...',
                icon: 'loading',
                duration: 1000
            });
            this.setData({
                loading: true
            });

            setTimeout(() => {
                this.setData({
                    loading: false,
                    isLoad: true
                });
             }, 1000);
        }
    },
    onHide() {
        getApp().globalData.openParams = ''
    },
    selectImage() {
        // if (this.getData('image')) {
        //     return;
        // }

        swan.showActionSheet({
            itemList: ['拍照', '从手机相册选择'],
            success: res => {
                const sourceType = res.tapIndex === 0 ? 'camera' : 'album';
                swan.chooseImage({
                    count: 1,
                    sizeType: ['original', 'compressed'],
                    sourceType: [sourceType],
                    success: image => {
                        this.setData({'image': image.tempFilePaths[0], loading: true});
                        this.recognition();
                        swan.showToast({
                            title: '识别中...',
                            icon: 'loading',
                            duration: 20000
                        });
                    },
                    fail: err => {}
                });
            }
        });
    },
    sumbit() {
        const result = swan.isLoginSync();
        if (!result.isLogin) {
            this.toast('请先登录再使用AI能力');
            return;
        }

        if (!this.getData('image')) {
            this.toast('请上传图片');
            return;
        }

        this.isNetConnect().then(() => {
            this.setData('loading', true);
            this.recognition();
        }).catch(() => {
            this.toast('网络不给力，请稍后重试');
        });
    },
    recognition() {
        swan.ai.ocrDrivingLicense({
            image: this.getData('image'),
            'detect_direction': true,
            'unified_valid_period': true,
            success: res => {
                console.log('ocrDrivingLicense succ', res);
                this.setRecognitionResult(res);
            },
            fail: err => {
                console.log('ocrDrivingLicense fail', err);
                this.setData('recognizeEnd', true);
            },
            complete: () => {
                this.setData('loading', false);
                swan.hideToast();
            }
        });
    },
    setRecognitionResult(data) {
        console.log('ceshi', data);
        const drivingLicenseInfoList = [];
        const len = dataScheme.length;
        const wordsResult = data.words_result;
        const direction = data.direction;
        let correctNum = 0;
        for (let i = 0; i < len; i++) {
            const key = dataScheme[i];
            let value = '未识别出结果';
            let error = true;
            if (wordsResult[key] && wordsResult[key].words) {
                value = wordsResult[key].words;
                error = false;
                correctNum++;
            }
            drivingLicenseInfoList[i] = {key, value, error};
            console.log('drivingLicenseInfoList', drivingLicenseInfoList);
        }

        if (correctNum < 4) {
            drivingLicenseInfoList.length = 0;
        }

        const imageDeg = direction > 0 ? direction * 90 : 0;
        const imageScale = direction % 2 === 1 ? 1.55 : 1;

        this.setData({imageDeg, imageScale, drivingLicenseInfoList, recognizeEnd: true});
    },
    clear() {
        if (!this.getData('image')) {
            this.toast('请上传图片');
            return;
        }

        if (this.getData('loading')) {
            return;
        }

        this.setData({
            image: '',
            loading: false,
            recognizeEnd: false,
            drivingLicenseInfoList: [],
            imageDeg: 0,
            imageScale: 1
        });
    },
    toast(title, icon = 'none') {
        swan.showToast({title, icon});
    },
    isNetConnect() {
        return new Promise((resolve, reject) => {
            swan.getNetworkType({
                success: res => {
                    if (res.networkType.toLowerCase() === 'none') {
                        reject();
                    }
                    resolve();
                },
                fail: reject
            });
        });
    }
});
