/**
 * @file demo api for ocrIdCard
 * @author swan
 */
/* globals Page, swan */

const dataScheme = {
    front: ['姓名', '性别', '民族', '出生', '住址', '身份证号'],
    back: ['签发机关', '签发日期', '失效日期']
};
const dateProcess = ['出生', '签发日期', '失效日期'];
const riskTypeData = ['copy', 'temporary', 'screen'];
const dataBackup = {
    front: {},
    back: {}
};

/* eslint-disable */
let app = getApp();

Page({
/* eslint-enable */
    data: {
        idCardSide: 'front',
        idCardSideDesc: '人像面',
        riskType: -1,
        editTool: '',
        image: '',
        loading: false,
        idCardInfoList: [
            {key: "姓名", value: "袁运筹", error: false},
            {key: "性别", value: "男", error: false},
            {key: "民族", value: "汉", error: false},
            {key: "出生", value: "1993年10月10日", error: false},
            {key: "住址", value: "北京市海淀区西北旺西山号院16栋", error: false},
            {key: "身份证号", value: "未识别出结果", error: true}], 
        recognizeEnd: false,
        imageDeg: 0,
        imageScale: 1,
        image: 'https://b.bdstatic.com/miniapp/image/idCardBack.png',
    },
    onLoad(e) {
        swan.getNetworkType({
            success: res => {
                this.setData('noNet', res.networkType === 'none');
            }
        });
        // this.setData('recognizeEnd', true);
        // this.changeCardSide();
    },
    onShow() {
        // 打点操作
        var openParams= app.globalData.openParams;
        if (openParams) {
            swan.reportAnalytics('pageshow', {
                fr: openParams,
                type: 'api',
                name: 'ocrBankCard',
           });
        }
    },
    onHide() {
        getApp().globalData.openParams = ''
    },
    changeCardSide(e) {
        // if (this.getData('loading')) {
        //     return;
        // }

        const idCardSide = e.currentTarget.dataset.idCardSide;
        const current = this.getData('idCardSide');
        console.log('current', current);
        console.log('idCardSide', idCardSide);
        
        if (idCardSide === current) {
            return;
        }
        
        const idCardSideDesc = idCardSide === 'front' ? '人像面' : '国徽面';
        const imageSrc = current === 'front' ? 'https://b.bdstatic.com/miniapp/image/idCardFront.png' : 'https://b.bdstatic.com/miniapp/image/idCardBack.png';
        // this.data.image = imageSrc;
        if (idCardSide === 'back'){
            let idCardInfoList = [
                {key: "签发机关", value: "北京市公安局海淀分局", error: false},
                {key: "签发日期", value: "2017年10月10日", error: false},
                {key: "失效日期", value: "2027年10月10日", error: false}]
            // this.setData('idCardInfoList', idCardInfoList);  
        }

        const {image, idCardInfoList, riskType, editTool, recognizeEnd, imageDeg, imageScale} = this.getData();
            dataBackup[current] = {
                image,
                idCardInfoList,
                riskType,
                editTool,
                recognizeEnd,
                imageDeg,
                imageScale
            };

        const restore = dataBackup[idCardSide];
        this.setData({
            idCardSide,
            idCardSideDesc,
            idCardInfoList,
            image: restore.image || '',
            idCardInfoList: restore.idCardInfoList || [],
            riskType: restore.riskType || -1,
            editTool: restore.editTool || '',
            recognizeEnd: restore.recognizeEnd || false,
            imageDeg: restore.imageDeg || 0,
            imageScale: restore.imageScale || 1
        });
    },
    sumbit() {
        const result = swan.isLoginSync();
        if (!result.isLogin) {
            this.toast('请先登录再使用AI能力');
            return;
        }

        if (!this.getData('image')) {
            this.toast('请上传图片');
            return;
        }

        this.isNetConnect().then(() => {
            this.setData('loading', true);
            this.recognition();
        }).catch(() => {
            this.toast('网络不给力，请稍后重试');
        });
    },
    recognition() {
        const {idCardSide, image} = this.getData();
        swan.ai.ocrIdCard({
            'detect_direction': true,
            'id_card_side': idCardSide,
            'detect_risk': true,
            image,
            success: res => {
                console.log('succ', res);
                this.setRecognitionResult(res);
            },
            fail: err => {
                console.log('fail', err);
                this.setData('recognizeEnd', true);
            },
            complete: () => {
                this.setData('loading', false);
            }
        });
    },
    setRecognitionResult(data) {
        const {
            'words_result': wordsResult,
            'risk_type': riskType,
            'edit_tool': editTool,
            'image_status': imageStatus,
            direction
        } = data;
        const idCardSide = this.getData('idCardSide');
        const showKeyList = dataScheme[idCardSide];
        const idCardInfoList = [];

        if (['normal', 'over_exposure', 'unknown'].indexOf(imageStatus) > -1) {
            riskType && this.setData('riskType', riskTypeData.indexOf(riskType));
            editTool && this.setData('editTool', editTool);
            let correctNum = 0;
            for (let i = 0; i < showKeyList.length; i++) {
                const key = showKeyList[i];
                let value = '未识别出结果';
                let error = true;
                if (wordsResult[key] && wordsResult[key].words) {
                    value = wordsResult[key].words;
                    error = false;
                    correctNum++;
                    if (dateProcess.indexOf(key) > -1) {
                        value = this.dateProcess(value);
                    }
                }
                idCardInfoList[i] = {key, value, error};
                console.log('idCardInfoList', idCardInfoList);
            }

            if (correctNum < 1) {
                idCardInfoList.length = 0;
            }
        }

        const imageDeg = direction > 0 ? direction * 90 : 0;
        const imageScale = direction % 2 === 1 ? 1.55 : 1;

        this.setData({imageDeg, imageScale, idCardInfoList, recognizeEnd: true});
    },
    selectImage() {
        swan.showActionSheet({
            itemList: ['拍照', '从手机相册选择'],
            success: res => {
                const sourceType = res.tapIndex === 0 ? 'camera' : 'album';
                swan.chooseImage({
                    count: 1,
                    sizeType: ['original', 'compressed'],
                    sourceType: [sourceType],
                    success: image => {
                        this.setData('image', image.tempFilePaths[0]);
                        this.recognition();
                    },
                    fail: err => {
                    }
                });
            }
        });
    },
    toast(title, icon = 'none') {
        swan.showToast({title, icon});
    },
    dateProcess(dateString) {
        if (dateString.length !== 8) {
            return dateString;
        }

        const year = dateString.substr(0, 4);
        const month = dateString.substr(4, 2);
        const day = dateString.substr(6, 2);
        return `${year}年${month}月${day}日`;
    },
    isNetConnect() {
        return new Promise((resolve, reject) => {
            swan.getNetworkType({
                success: res => {
                    if (res.networkType.toLowerCase() === 'none') {
                        reject();
                    }
                    resolve();
                },
                fail: reject
            });
        });
    }
});