/**
 * @file demo api for ocrVehicleLicense
 * @author swan
 */
/* globals Page, swan */
const dataScheme = ['号牌号码', '车辆类型', '所有人', '住址', '使用性质',
    '品牌型号', '车辆识别代号', '发动机号码', '注册日期', '发证日期'];

/* eslint-disable */
let app = getApp();

Page({
    /* eslint-enable */
    data: {
        vehicleLicenseInfoList: [
            {key: Array(4), value: '粤BC78C7', error: false},
            {key: Array(4), value: '小型轿车', error: false},
            {key: Array(3), value: '江东东', error: false},
            {key: Array(2), value: '广东省金金县金金镇中埔村谢本本', error: false},
            {key: Array(4), value: '非营运', error: false},
            {key: Array(4), value: '凌派牌HG71717171', error: false},
            {key: Array(6), value: 'LHGGJG631E8814971', error: false},
            {key: Array(5), value: '15151515', error: false},
            {key: Array(4), value: '20140918', error: false},
            {key: Array(4), value: '20140918', error: false}],
        image: '',
        loading: true,
        isLoad: false,
        recognizeEnd: true,
        imageDeg: 0,
        imageScale: 1,
        image: 'https://b.bdstatic.com/miniapp/image/ocrVehicleLicense.png'
    },
    onLoad(e) {
    },
    onShow() {
        // 打点操作
        var openParams= app.globalData.openParams;
        if (openParams) {
            swan.reportAnalytics('pageshow', {
                fr: openParams,
                type: 'api',
                name: 'ocrVehicleLicense',
           });
        }

        for (let i = 0; i < dataScheme.length; i++) {
            let dataSchemeKey = dataScheme[i].split('') 
            let vehicleLicenseInfoList = this.getData('vehicleLicenseInfoList')
            vehicleLicenseInfoList[i].key =  dataSchemeKey;
            this.setData("vehicleLicenseInfoList", vehicleLicenseInfoList)

        }
        if (!this.getData('isLoad')) {
            swan.showToast({
                title: '识别中...',
                icon: 'loading',
                duration: 1000
            });
            this.setData({
                loading: true
            });

            setTimeout(() => {
                this.setData({
                    loading: false,
                    isLoad: true
                });
             }, 1000);
        }
    },
    onHide() {
        getApp().globalData.openParams = ''
    },
    selectImage() {
        // if (this.getData('image')) {
        //     return;
        // }

        swan.showActionSheet({
            itemList: ['拍照', '从手机相册选择'],
            success: res => {
                const sourceType = res.tapIndex === 0 ? 'camera' : 'album';
                swan.chooseImage({
                    count: 1,
                    sizeType: ['original', 'compressed'],
                    sourceType: [sourceType],
                    success: image => {
                        this.setData({'image': image.tempFilePaths[0], loading: true});
                        swan.showToast({
                            title: '识别中...',
                            icon: 'loading',
                            duration: 20000
                        });
                        this.recognition();
                    },
                    fail: err => {}
                });
            }
        });
    },
    sumbit() {
        const result = swan.isLoginSync();
        if (!result.isLogin) {
            this.toast('请先登录再使用AI能力');
            return;
        }

        if (!this.getData('image')) {
            this.toast('请上传图片');
            return;
        }

        if (this.getData('noNet')) {
            this.toast('网络不给力，请稍后重试');
            return;
        }

        this.isNetConnect().then(() => {
            this.setData('loading', true);
            this.recognition();
        }).catch(() => {
            this.toast('网络不给力，请稍后重试');
        });
    },
    recognition() {
        console.log('selectImage', this.getData('image'));
        swan.ai.ocrVehicleLicense({
            image: this.getData('image'),
            detect_direction: true,
            // accuracy: normal,
            success: res => {
                console.log('ocrVehicleLicense succ', res);
                if(res.words_result_num === 0){
                    this.setData('recognizeEnd', false);
                }
                else{
                    this.setRecognitionResult(res);
                }
            },
            fail: err => {
                console.log('ocrVehicleLicense fail', err);
                this.setData('recognizeEnd', false);
            },
            complete: () => {
                this.setData('loading', false);
                swan.hideToast();
            }
        });
    },
    setRecognitionResult(data) {
        console.log('setRecognitionResult');

        const vehicleLicenseInfoList = [];
        const len = dataScheme.length;
        const wordsResult = data.words_result;
        const direction = data.direction;

        for (let i = 0; i < len; i++) {
            const key = dataScheme[i];
            let value = '未识别出结果';
            let error = true;
            if (wordsResult[key] && wordsResult[key].words) {
                value = wordsResult[key].words;
                error = false;
            }
            console.log('vehicleLicenseInfoList', vehicleLicenseInfoList)
            vehicleLicenseInfoList[i] = {key: key.split(''), value, error};
        }

        const imageDeg = direction > 0 ? direction * 90 : 0;
        const imageScale = direction % 2 === 1 ? 1.55 : 1;

        this.setData({imageDeg, imageScale, vehicleLicenseInfoList});
        this.setData('recognizeEnd', true);
    },
    clear() {
        if (!this.getData('image')) {
            this.toast('请上传图片');
            return;
        }

        if (this.getData('loading')) {
            return;
        }

        this.setData({
            image: '',
            loading: false,
            recognizeEnd: false,
            vehicleLicenseInfoList: [],
            imageDeg: 0,
            imageScale: 1
        });
    },
    toast(title, icon = 'none') {
        swan.showToast({title, icon});
    },
    isNetConnect() {
        return new Promise((resolve, reject) => {
            swan.getNetworkType({
                success: res => {
                    if (res.networkType.toLowerCase() === 'none') {
                        reject();
                    }
                    resolve();
                },
                fail: reject
            });
        });
    }
});
