/**
 * @file search page
 * @author swan
 */
/* globals Page, swan */

import {componentDictionary, apiDictionary} from './dictionary';

/* eslint-disable */
let app = getApp();

Page({
    /* eslint-enable */
    data: {
        value: '',
        focus: true,
        component: [],
        api: [],
        history: [],
        hot: [{subName: '支付', id: 'payment'},
        {subName: '拨打电话', id: 'makePhoneCall'},
        {subName: '语音识别', id: 'getVoiceManager'},
        {subName: '车型识别', id: 'carClassify'},
        {subName: '动物识别', id: 'animalClassify'},
        {subName: '植物识别', id: 'plantClassify'},
        {subName: '设置页面标题', id: 'setNavigationBarTitle'}],
        hasResult: false,
        hasHistory: true,
        showEmptyResult: false,
        blur: true,
        inputColor: true
    },
    onShow() {
        this.getHistoryStorage();
    },
    searchFocus(e) {
        this.setData({
            focus: true,
            inputColor: true
        });
    },
    searchInput(e) {
        const value = e.detail.value;
        this.setData({
            value,
            component: [],
            api: [],
            hasResult: false,
            showEmptyResult: false
        });
        if (!value) {
            this.resetResult();
            return false;
        }

        if (value.length === 1 && /[a-zA-Z]/.test(value)) {
            this.resetResult();
            return false;
        }
        this.getSearchResult(value);
    },
    searchConfirm(e) {
        const value = this.getData('value').replace(/\s/gi, '');
        if (value) {
            this.setData({
                showEmptyResult: true,
                hasHistory: true

            });
            this.getSearchResult(value);
            this.setHistoryStorage(value);
        }
    },
    searchBlur(e) {
        this.setData({
            focus: false,
            inputColor: false
        });
    },
    searchClear() {
        this.setData({
            value: '',
            component: [],
            api: [],
            hasResult: false,
            showEmptyResult: false
        });
    },
    historyClear() {
        var that = this;
        swan.showModal({
            content: '确定清空相关历史？',
            confirmText: '确定',
            cancelText: '取消',
            success: res =>  {
                if (res.cancel) {
                }
                else if (res.confirm) {
                    that.setData({
                        history: [],
                        hasHistory: false
                    });
                    swan.clearStorageSync('history');
                }
            }
        });
    },
    getSearchResult(value) {
        const component = componentDictionary.filter(item => item.subName.indexOf(value) > -1 || item.id.indexOf(value) > -1);
        const api = apiDictionary.filter(item => item.subName.indexOf(value) > -1 || item.id.indexOf(value) > -1);
        const hasResult = component.length || api.length;
        this.setData({component, api, hasResult});
    },
    resetResult() {
        this.setData({
            component: [],
            api: [],
            hasResult: false
        });
    },
    openPage(e) {
        const item = e.currentTarget.dataset.item;
        const {id, subName} = item;
        swan.navigateTo({
            url: `/pages/${id}/${id}`,
            success: () => {
                this.setHistoryStorage(subName)
            }
        });
    },
    setHistoryStorage(value) {
        const history = this.getData('history');
        const index = history.findIndex(item => item === value);
        if (index > -1) {
            history.splice(index, 1);
        }
        history.unshift(value);
        swan.setStorageSync('history', history);
        this.setData('history', history);
    },
    getHistoryStorage() {
        let history = swan.getStorageSync('history');
        if (history.length === 0) {
            this.setData('hasHistory', false);
        }
        else {
            this.setData('hasHistory', true);
        }
        if (!Array.isArray(history)) {
            history = [];
        }
        this.setData('history', history);
    },
    openSearch(e) {
        const word = e.currentTarget.dataset.word;
        this.setData({value: word});
        this.getSearchResult(word);
        this.searchConfirm(word);
    }
});
