/**
 * @file demo api for storage
 * @author swan
 */
/* globals Page, swan */

let app = getApp();

Page({
    data: {
        key: '示例Key',
        value: '示例Value',
        disabled: true
    },
    onLoad(e) {
    },
    onShow() {
        // 打点操作
        var openParams= app.globalData.openParams;
        if (openParams) {
            swan.reportAnalytics('pageshow', {
                fr: openParams,
                type: 'api',
                name: 'storage',
           });
        }
    },
    onHide() {
        getApp().globalData.openParams = ''
    },
    keyInput(e) {
        this.setData('key', e.detail.value);
    },
    valueInput(e) {
        this.setData('value', e.detail.value);
    },
    setStorage() {
        let key = this.hasKey();
        if (!key) {
            return;
        }
        swan.setStorage({
            key,
            data: this.getData('value'),
            success: res => {
                this.toast('存储成功', 'none');
                this.setData('disabled', false);
            },
            fail: err => {
                this.toast('存储数据失败');
            }
        });
    },
    getStorage() {
        let key = this.hasKey();
        if (!key) {
            return;
        }
        swan.getStorage({
            key,
            success: res => {
                const data = res.data;
                if (data) {
                    swan.showModal({
                        title: '数据信息',
                        content: `${key}: ${data}`,
                        showCancel: false
                    });
                } else {
                    this.toast('找不到key对应的值');
                }
            },
            fail: err => {
                this.toast('读取数据失败');
            }
        });
    },
    clearStorage() {
        swan.clearStorageSync();
        this.toast('后台数据已清除', 'none');
        this.setData('disabled', true);
    },
    getStorageInfo() {
        swan.getStorageInfo({
            success: res => {
                swan.showModal({
                    title: '存储数据信息',
                    content: JSON.stringify(res),
                    showCancel: 'false'
                })
                console.log('getStorageInfo success', res);
            },
            fail: err => {
                console.log('getStorageInfo fail', err);
            }
        });
    },
    hasKey() {
        let key = this.getData('key');
        if (key) {
            return key;
        }
        this.toast('key不能为空');
    },
    toast(title, icon = 'none') {
        swan.showToast({title, icon});
    }
});
