/**
 * @file demo ai for textReview
 * @author swan
 */

/* globals Page, swan */
/* eslint-disable */
let app = getApp();

Page({
    /* eslint-enable */
    data: {
        text: '',
        textResult: '',
        loading: false,
        passed: true,
        detail: []
    },
    onLoad(e) {
    },

    onShow() {
        var openParams = app.globalData.openParams;
        if (openParams) {
            swan.reportAnalytics('pageshow', {
                fr: openParams,
                type: 'api',
                name: 'textReview',
            });
        }
    },
    onHide() {
        getApp().globalData.openParams = ''
    },
    bindInput(e) {
        let len = parseInt(e.detail.value.length, 10);
        if (len >= 6000) {
            this.toast('审核上限6000字');
            return;
        }
        this.setData('text', e.detail.value);
    },
    submitReview() {
        this.setData({
            passed: true,
            detail: [],
            textResult: ''
        });

        const text = this.getData('text');
        if (text.length === 0) {
            this.toast('请输入文本');
            return;
        }

        this.isNetConnect().then(() => {
            this.setData('loading', true);
            this.textReview(text);
        }).catch(() => {
            this.toast('网络不给力，请稍后重试');
        });
    },
    textReview(text) {
        swan.ai.textReview({
            content: text.replace(/\s+/g, ''),
            success: res => {
                this.setReviewResult(res);
            },
            fail: err => {
                if (err.status === 1001) {
                    this.toast('网络不给力，请稍后重试');
                }
            },
            complete: () => {
                this.setData('loading', false);
            }
        });
    },
    setReviewResult(data) {
        let detail = [];
        let textResult = '';
        let passed = true;
        const result = data.result;

        if (result.spam === 0) {
            detail = result.review;
            textResult = '通过';
            passed = true;
        } else {
            textResult = result.spam === 1 ? '疑似违规' : '违规';
            passed = false;

            detail = result.review;
            detail = detail.concat(result.reject);

            for (let i = 0; i < detail.length; i++) {
                detail[i].score = detail[i].score.toFixed(2);
                switch (detail[i].label) {
                    case 1:
                        detail[i].text = '暴恐违禁';
                        break;
                    case 2:
                        detail[i].text = '文本色情';
                        break;
                    case 3:
                        detail[i].text = '政治敏感';
                        break;
                    case 4:
                        detail[i].text = '恶意推广';
                        break;
                    case 5:
                        detail[i].text = '低俗辱骂';
                        break;
                }
            }
        }
        this.setData({detail, textResult, passed});
    },
    clearText() {
        const text = this.getData('text');
        if (text.length === 0) {
            this.toast('请输入文本');
        }
        this.setData({
            text: '',
            textResult: '',
            loading: false,
            passed: true,
            detail: []
        });
    },
    toast(title, icon = 'none') {
        swan.showToast({title, icon});
    },
    isNetConnect() {
        return new Promise((resolve, reject) => {
            swan.getNetworkType({
                success: res => {
                    if (res.networkType.toLowerCase() === 'none') {
                        reject();
                    }
                    resolve();
                },
                fail: reject
            });
        });
    }
});
