const automator = require('swan-automator');
const path = require('path');

describe('component', () => {
    let smartProgram;
    let page;

    beforeAll(async () => {
        smartProgram = await automator.launch({
            projectPath: path.join(__dirname, '..')
        });
        // await smartProgram.remote(); // 扫码连接成功后在真机上执行自动化脚本
        page = await smartProgram.reLaunch('/pages/component/component');
    }, 2 * 60 * 1e3); // 这里需要延长超时时间确保工具启动和编译完成，如果在真机运行则需要更长时间用于生成预览二维码以及扫码

    afterAll(async () => {
        await smartProgram.close();
    });

    it('text', async () => {
        const text = await page.$('text');
        expect(text.tagName).toBe('text');
        expect(await text.text()).toContain('搜索组件和接口');
    });

    it('items', async () => {
        const lists = await page.$$('.item');
        expect(lists.length).toBe(8);
        const list = await lists[0].$('.item-desc');
        expect(await list.text()).toBe('视图容器');
    });

    it('item action', async () => {
        const className = 'item-close';
        const firstItem = await page.$('.item');
        expect(await firstItem.attribute('class')).toContain(className);
        await firstItem.tap();
        expect(await firstItem.attribute('class')).toEqual(expect.not.stringContaining(className));
        await firstItem.tap();
        expect(await firstItem.attribute('class')).toContain(className);

        await firstItem.tap();
        const subItem = await page.$('.sub-item');
        await subItem.tap();
        await page.waitFor(500);
        expect((await smartProgram.currentPage()).path).toBe('pages/view/view');
    });
});
